@@ -1,3 +1,4 @@
+// Package client represents the CLI UI for adsysctl client.
 package client
 
 import (
@@ -5,14 +6,14 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/leonelquinteros/gotext"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/ubuntu/adsys/internal/cmdhandler"
 	"github.com/ubuntu/adsys/internal/config"
 	"github.com/ubuntu/adsys/internal/consts"
-	"github.com/ubuntu/adsys/internal/decorate"
 	"github.com/ubuntu/adsys/internal/grpc/grpcerror"
-	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/ubuntu/decorate"
 )
 
 // CmdName is the binary name for the client.
@@ -41,12 +42,12 @@ func New() *App {
 	a.ctx, a.cancel = context.WithCancel(context.Background())
 	a.rootCmd = cobra.Command{
 		Use:   fmt.Sprintf("%s COMMAND", CmdName),
-		Short: i18n.G("AD integration client"),
-		Long:  i18n.G(`Active Directory integration bridging toolset command line tool.`),
+		Short: gotext.Get("AD integration client"),
+		Long:  gotext.Get(`Active Directory integration bridging toolset command line tool.`),
 		PersistentPreRunE: func(cmd *cobra.Command, args []string) error {
 			// command parsing has been successful. Returns runtime (or configuration) error now and so, don’t print usage.
 			a.rootCmd.SilenceUsage = true
-			return config.Init("adsys", a.rootCmd, a.viper, func(refreshed bool) error {
+			err := config.Init("adsys", a.rootCmd, a.viper, func(refreshed bool) error {
 				var newConfig daemonConfig
 				if err := config.LoadConfig(&newConfig, a.viper); err != nil {
 					return err
@@ -74,6 +75,9 @@ func New() *App {
 				// Timeout reload is ignored
 				return nil
 			})
+			// Set configured verbose status for the daemon.
+			config.SetVerboseMode(a.config.Verbose)
+			return err
 		},
 		Args: cmdhandler.SubcommandsRequiredWithSuggestions,
 		RunE: cmdhandler.NoCmd,
@@ -83,10 +87,10 @@ func New() *App {
 	a.viper = viper.New()
 
 	cmdhandler.InstallVerboseFlag(&a.rootCmd, a.viper)
-	cmdhandler.InstallConfigFlag(&a.rootCmd)
+	cmdhandler.InstallConfigFlag(&a.rootCmd, true)
 	cmdhandler.InstallSocketFlag(&a.rootCmd, a.viper, consts.DefaultSocket)
 
-	a.rootCmd.PersistentFlags().IntP("timeout", "t", consts.DefaultClientTimeout, i18n.G("time in seconds before cancelling the client request when the server gives no result. 0 for no timeout."))
+	a.rootCmd.PersistentFlags().IntP("timeout", "t", consts.DefaultClientTimeout, gotext.Get("time in seconds before cancelling the client request when the server gives no result. 0 for no timeout."))
 	decorate.LogOnError(a.viper.BindPFlag("client_timeout", a.rootCmd.PersistentFlags().Lookup("timeout")))
 
 	// subcommands
@@ -130,6 +134,6 @@ func (a App) getTimeout() time.Duration {
 }
 
 // SetArgs changes the root command args. Shouldn’t be in general necessary apart for integration tests.
-func (a *App) SetArgs(args []string) {
+func (a *App) SetArgs(args ...string) {
 	a.rootCmd.SetArgs(args)
 }
