@@ -1,3 +1,5 @@
+// Package daemon handles the GRPC daemon with systemd activation, configuration changes like dynamic
+// socket listening, idling timeout functionality.
 package daemon
 
 import (
@@ -8,16 +10,16 @@ import (
 	"sync"
 	"time"
 
-	"github.com/coreos/go-systemd/activation"
-	"github.com/coreos/go-systemd/daemon"
-	"github.com/ubuntu/adsys/internal/decorate"
+	"github.com/coreos/go-systemd/v22/activation"
+	"github.com/coreos/go-systemd/v22/daemon"
 	log "github.com/ubuntu/adsys/internal/grpc/logstreamer"
 	"github.com/ubuntu/adsys/internal/i18n"
+	"github.com/ubuntu/decorate"
 	"google.golang.org/grpc"
 )
 
 // Daemon is a grpc daemon with systemd activation, configuration changes like dynamic
-// socket listening, idling timeout functionality…
+// socket listening, idling timeout functionality….
 type Daemon struct {
 	grpcserver         *grpc.Server
 	registerGRPCServer GRPCServerRegisterer
@@ -45,7 +47,7 @@ type options struct {
 
 type option func(*options) error
 
-// GRPCServerRegisterer is a function that the daemon will call everytime we want to build a new GRPC object
+// GRPCServerRegisterer is a function that the daemon will call everytime we want to build a new GRPC object.
 type GRPCServerRegisterer func(srv *Daemon) *grpc.Server
 
 // WithTimeout adds a timeout to the daemon. A 0 duration means no timeout.
@@ -151,7 +153,7 @@ func (d *Daemon) UseSocket(socket string) (err error) {
 // Listen serves on its unix socket path.
 // It handles systemd activation notification.
 // When the server stop listening, the socket is removed automatically.
-// Configuration can be reloaded and we will then listen on the new socket
+// Configuration can be reloaded and we will then listen on the new socket.
 func (d *Daemon) Listen() (err error) {
 	defer decorate.OnError(&err, i18n.G("can't serve"))
 
@@ -170,7 +172,7 @@ func (d *Daemon) Listen() (err error) {
 	for {
 		log.Infof(context.Background(), i18n.G("Serving on %s"), lis.Addr().String())
 		if err := (d.grpcserver.Serve(lis)); err != nil {
-			return fmt.Errorf("unable to start GRPC server: %s", err)
+			return fmt.Errorf("unable to start GRPC server: %w", err)
 		}
 
 		// check if we need to reconnect using a new socket
